@@ -1,5 +1,5 @@
 from .app import Jettask
 from .task import Task, Request, ExecuteResponse
-from .event_pool import EventPool
+from jettask.messaging.event_pool import EventPool
 
 __all__ = ["Jettask", "Task", "Request", "ExecuteResponse", "EventPool"]
\ No newline at end of file
